Author: Aloha Editor Team

Aloha Editor Demo
Edit Save

Loading Aloha Editor

# Aloha, world!

This is a demo application using Aloha Editor to edit content using contentEditables.

You can download the source code with Aloha Editor on github. In this demo application you can store the changes to a backend (database, session, file).

Send Feedback »

## Web Page

See how easy it is to edit web pages with Aloha Editor.

We provide you with examples to integrate Aloha Editor in your system. Learn how to connect your backend to store edited content and create a Aloha Plugin for your own link suggestions.

View demo »

## Article

Edit a 3 column text with Aloha Editor and see the result in realtime.

This shows what you can do with modern web technologies like CSS3 and HTML5.

View demo »

## CMS Textarea

Replace your existing CMS WYSIWYG Editor with Aloha. With Aloha Editor you can also use traditional textareas.

View demo »

## Download Aloha

Download Aloha Editor from our website.

Download »